# Documentation

This folder contains infrastructure to build documentation using `sphinx`. To build
using this infrastructure, install the dependencies using `pipenv`.

- On Windows, execute `main.bat` from this folder.
- On Linux/Mac, execute `sphinx-build source build`
